spacepy.omni.omnirange — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- omni - module to read and process NASA OMNIWEB data »

# spacepy.omni.omnirange

`spacepy.omni.` `omnirange`(dbase='QDhourly')

  Returns datetimes giving start and end times in the OMNI/Qin-Denton data

  The update function in toolbox retrieves all available hourly Qin-Denton data, and this function accesses that and looks up the start and end times, returning them as datetime objects.

  Parameters: | dbase : string (optional) name of omni database to check. Currently ‘QDhourly’ and ‘OMNI2hourly’
  Returns: | omnirange : tuple containing two datetimes giving the start and end times of the available data

  Examples

      >>> import spacepy.omni as om
      >>> om.omnirange()
      (datetime.datetime(1963, 1, 1, 0, 0), datetime.datetime(2011, 11, 30, 23, 0))
      >>> om.omnirange(dbase='OMNI2hourly')
      (datetime.datetime(1963, 1, 1, 0, 0), datetime.datetime(2011, 11, 30, 23, 0))

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- omni - module to read and process NASA OMNIWEB data »